@@ -2,9 +2,9 @@ import sys
 
 if __name__ == "__main__":
     try:
-        from urllib.request import urlopen, URLError
+        from urllib.request import URLError, urlopen
     except ImportError:
-        from urllib2 import urlopen, URLError
+        from urllib2 import URLError, urlopen
 
     url = sys.argv[1]
     headers = {"Content-Type": "text/plain; charset=utf-8"}
